DiscoveryBehaviour

Struct DiscoveryBehaviour 

pub struct DiscoveryBehaviour {
    pub mdns: Behaviour,
    pub kademlia: Behaviour<MemoryStore>,
}
The libp2p network behaviour for peer discovery.

Fields

mdns: Behaviour

The mDNS behaviour for local peer discovery.

kademlia: Behaviour<MemoryStore>

The Kademlia behaviour for decentralized peer discovery.

Implementations

Source

impl DiscoveryBehaviour

pub fn new(local_peer_id: PeerId) -> Result<Self>

Creates a new DiscoveryBehaviour.

Arguments
  • local_peer_id - The PeerId of the local node.
Errors

This function will return an error if the mDNS behaviour cannot be created.

pub fn bootstrap(&mut self) -> Result<()>

Bootstraps the Kademlia DHT.

This will start the process of finding other peers in the network.

Errors

This function will return an error if the bootstrap process fails.

pub fn start_providing(&mut self, key: RecordKey) -> Result<()>

Starts providing a key in the Kademlia DHT.

This announces to the network that the local node can provide information about the given key.

Arguments
  • key - The key to start providing.
Errors

This function will return an error if the providing process fails to start.

pub fn get_providers(&mut self, key: RecordKey) -> QueryId

Gets the providers for a given key from the Kademlia DHT.

Arguments
  • key - The key to get providers for.
Returns

A QueryId for the get providers query.

pub fn add_peer_address(&mut self, peer_id: PeerId, address: Multiaddr)

Adds a known address for a peer to the Kademlia DHT.

Arguments
  • peer_id - The PeerId of the peer.
  • address - The Multiaddr of the peer.