pub struct DiscoveryBehaviour {
pub mdns: Behaviour,
pub kademlia: Behaviour<MemoryStore>,
}Expand description
The libp2p network behaviour for peer discovery.
Fields
mdns: BehaviourThe mDNS behaviour for local peer discovery.
kademlia: Behaviour<MemoryStore>The Kademlia behaviour for decentralized peer discovery.
Implementations
Sourceimpl DiscoveryBehaviour
impl DiscoveryBehaviour
Sourcepub fn bootstrap(&mut self) -> Result<()>
pub fn bootstrap(&mut self) -> Result<()>
Bootstraps the Kademlia DHT.
This will start the process of finding other peers in the network.
Errors
This function will return an error if the bootstrap process fails.
Sourcepub fn start_providing(&mut self, key: RecordKey) -> Result<()>
pub fn start_providing(&mut self, key: RecordKey) -> Result<()>
Sourcepub fn get_providers(&mut self, key: RecordKey) -> QueryId
pub fn get_providers(&mut self, key: RecordKey) -> QueryId
Sourcepub fn add_peer_address(&mut self, peer_id: PeerId, address: Multiaddr)
pub fn add_peer_address(&mut self, peer_id: PeerId, address: Multiaddr)
Adds a known address for a peer to the Kademlia DHT.
Arguments
peer_id- ThePeerIdof the peer.address- TheMultiaddrof the peer.